A "jSA" object is a list with three elements:
"result": the Java object with the results of a seasonal adjustment or a pre-adjustment method.
"spec": the Java object with the specification of a seasonal adjustment or a pre-adjustment method.
"dictionary": the Java object with dictionnary of a seasonal adjustment or a pre-adjustment method. In particular, it contains all the user-defined regressors.
get_dictionary returns the list of indicators that can be extracted from a jSA object by the function get_indicators.
jSA2R returns the corresponding formatted seasonal adjustment ("SA" object) or RegARIMA ("regarima" object) model.
get_jspec returns the Java object that contains the specification from an object
"jSA", "X13", "TRAMO_SEATS" or "sa_item".